@@ -1,8 +1,10 @@
 package Mojolicious;
 use Mojo::Base 'Mojo';
 
+# "Fry: Shut up and take my money!"
 use Carp 'croak';
 use Mojo::Exception;
+use Mojo::Util qw(decamelize deprecated);
 use Mojolicious::Commands;
 use Mojolicious::Controller;
 use Mojolicious::Plugins;
@@ -13,17 +15,21 @@ use Mojolicious::Static;
 use Mojolicious::Types;
 use Scalar::Util qw(blessed weaken);
 
-# "Robots don't have any emotions, and sometimes that makes me very sad."
-has commands => sub { Mojolicious::Commands->new };
+has commands => sub {
+  my $commands = Mojolicious::Commands->new(app => shift);
+  weaken $commands->{app};
+  return $commands;
+};
 has controller_class => 'Mojolicious::Controller';
-has mode => sub { ($ENV{MOJO_MODE} || 'development') };
+has mode => sub { $ENV{MOJO_MODE} || 'development' };
+has moniker  => sub { decamelize ref shift };
 has plugins  => sub { Mojolicious::Plugins->new };
 has renderer => sub { Mojolicious::Renderer->new };
 has routes   => sub { Mojolicious::Routes->new };
 has secret   => sub {
   my $self = shift;
 
-  # Warn developers about unsecure default
+  # Warn developers about insecure default
   $self->log->debug('Your secret passphrase needs to be changed!!!');
 
   # Default to application name
@@ -33,75 +39,57 @@ has sessions => sub { Mojolicious::Sessions->new };
 has static   => sub { Mojolicious::Static->new };
 has types    => sub { Mojolicious::Types->new };
 
-our $CODENAME = 'Leaf Fluttering In Wind';
-our $VERSION  = '2.98';
+our $CODENAME = 'Rainbow';
+our $VERSION  = '3.97';
 
-# "These old doomsday devices are dangerously unstable.
-#  I'll rest easier not knowing where they are."
 sub AUTOLOAD {
   my $self = shift;
 
-  # Method
-  my ($package, $method) = our $AUTOLOAD =~ /^([\w:]+)\:\:(\w+)$/;
+  my ($package, $method) = our $AUTOLOAD =~ /^([\w:]+)::(\w+)$/;
   croak "Undefined subroutine &${package}::$method called"
     unless blessed $self && $self->isa(__PACKAGE__);
 
-  # Check for helper
+  # Call helper with fresh controller
   croak qq{Can't locate object method "$method" via package "$package"}
     unless my $helper = $self->renderer->helpers->{$method};
-
-  # Call helper with fresh controller
   return $self->controller_class->new(app => $self)->$helper(@_);
 }
 
 sub DESTROY { }
 
-# "I personalized each of your meals.
-#  For example, Amy: you're cute, so I baked you a pony."
 sub new {
   my $self = shift->SUPER::new(@_);
 
-  # Paths
   my $home = $self->home;
   push @{$self->renderer->paths}, $home->rel_dir('templates');
   push @{$self->static->paths},   $home->rel_dir('public');
 
   # Default to application namespace
-  my $r = $self->routes->namespace(ref $self);
+  my $r = $self->routes->namespaces([ref $self]);
 
   # Hide controller attributes/methods and "handler"
   $r->hide(qw(AUTOLOAD DESTROY app cookie finish flash handler on param));
-  $r->hide(qw(redirect_to render render_content render_data));
-  $r->hide(qw(render_exception render_json render_not_found render_partial));
-  $r->hide(qw(render_static render_text rendered req res respond_to send));
-  $r->hide(qw(session signed_cookie stash tx ua url_for write write_chunk));
+  $r->hide(qw(redirect_to render render_data render_exception render_json));
+  $r->hide(qw(render_not_found render_partial render_static render_text));
+  $r->hide(qw(rendered req res respond_to send session signed_cookie stash));
+  $r->hide(qw(tx ua url_for write write_chunk));
 
-  # Prepare log
+  # Check if we have a log directory
   my $mode = $self->mode;
   $self->log->path($home->rel_file("log/$mode.log"))
     if -w $home->rel_file('log');
 
-  # Load default plugins
   $self->plugin($_) for qw(HeaderCondition DefaultHelpers TagHelpers);
   $self->plugin($_) for qw(EPLRenderer EPRenderer RequestTimer PoweredBy);
 
-  # Exception handling
-  $self->hook(
-    around_dispatch => sub {
-      my ($next, $c) = @_;
-      local $SIG{__DIE__}
-        = sub { ref $_[0] ? CORE::die($_[0]) : Mojo::Exception->throw(@_) };
-      $c->render_exception($@) unless eval { $next->(); 1 };
-    }
-  );
+  # Exception handling should be first in chain
+  $self->hook(around_dispatch => \&_exception);
 
   # Reduced log output outside of development mode
   $self->log->level('info') unless $mode eq 'development';
 
-  # Run mode
+  # Run mode before startup
   if (my $sub = $self->can("${mode}_mode")) { $self->$sub(@_) }
-
-  # Startup
   $self->startup(@_);
 
   return $self;
@@ -126,71 +114,65 @@ sub dispatch {
   my $plugins = $self->plugins->emit_hook(before_dispatch => $c);
 
   # Try to find a static file
-  $self->static->dispatch($c);
-  $plugins->emit_hook_reverse(after_static_dispatch => $c);
+  $self->static->dispatch($c) and $plugins->emit_hook(after_static => $c)
+    unless $tx->res->code;
+
+  # DEPRECATED in Rainbow!
+  if ($plugins->has_subscribers('after_static_dispatch')) {
+    deprecated
+      'after_static_dispatch hook is DEPRECATED in favor of before_routes'
+      and $plugins->emit_hook_reverse(after_static_dispatch => $c);
+  }
 
   # Routes
+  $plugins->emit_hook(before_routes => $c);
   my $res = $tx->res;
   return if $res->code;
   if (my $code = ($tx->req->error)[1]) { $res->code($code) }
   elsif ($tx->is_websocket) { $res->code(426) }
-  $c->render_not_found unless $self->routes->dispatch($c) || $res->code;
+  $c->render_not_found unless $self->routes->dispatch($c) || $tx->res->code;
 }
 
-# "Bite my shiny metal ass!"
 sub handler {
   my ($self, $tx) = @_;
 
   # Embedded application
   my $stash = {};
   if (my $sub = $tx->can('stash')) { ($stash, $tx) = ($tx->$sub, $tx->tx) }
+  $stash->{'mojo.secret'} //= $self->secret;
 
   # Build default controller
   my $defaults = $self->defaults;
   @{$stash}{keys %$defaults} = values %$defaults;
   my $c
     = $self->controller_class->new(app => $self, stash => $stash, tx => $tx);
-  weaken $c->{app};
-  weaken $c->{tx};
+  weaken $c->{$_} for qw(app tx);
 
-  # Dispatcher
-  unless ($self->{dispatch}) {
-    $self->hook(
-      around_dispatch => sub {
-        my ($next, $c) = @_;
-        $c->app->dispatch($c);
-      }
-    );
-    $self->{dispatch}++;
-  }
+  # Dispatcher has to be last in the chain
+  ++$self->{dispatch}
+    and $self->hook(around_dispatch => sub { $_[1]->app->dispatch($_[1]) })
+    unless $self->{dispatch};
 
-  # Process
+  # Process with chain
   unless (eval { $self->plugins->emit_chain(around_dispatch => $c) }) {
     $self->log->fatal("Processing request failed: $@");
     $tx->res->code(500);
     $tx->resume;
   }
 
-  # Delayed
-  $self->log->debug('Nothing has been rendered, assuming delayed response.')
+  # Delayed response
+  $self->log->debug('Nothing has been rendered, expecting delayed response.')
     unless $stash->{'mojo.rendered'} || $tx->is_writing;
 }
 
 sub helper {
-  my ($self, $name) = (shift, shift);
+  my ($self, $name, $cb) = @_;
   my $r = $self->renderer;
   $self->log->debug(qq{Helper "$name" already exists, replacing.})
     if exists $r->helpers->{$name};
-  $r->add_helper($name, @_);
+  $r->add_helper($name => $cb);
 }
 
-# "He knows when you are sleeping.
-#  He knows when you're on the can.
-#  He'll hunt you down and blast your ass, from here to Pakistan.
-#  Oh...
-#  You better not breathe, you better not move.
-#  You're better off dead, I'm tellin' you, dude.
-#  Santa Claus is gunning you down!"
 sub hook { shift->plugins->on(@_) }
 
 sub plugin {
@@ -198,10 +180,17 @@ sub plugin {
   $self->plugins->register_plugin(shift, $self, @_);
 }
 
-sub start { ($ENV{MOJO_APP} = shift)->commands->start(@_) }
+sub start { shift->commands->run(@_ ? @_ : @ARGV) }
 
 sub startup { }
 
+sub _exception {
+  my ($next, $c) = @_;
+  local $SIG{__DIE__}
+    = sub { ref $_[0] ? CORE::die($_[0]) : Mojo::Exception->throw(@_) };
+  $c->render_exception($@) unless eval { $next->(); 1 };
+}
+
 1;
 
 =head1 NAME
@@ -227,7 +216,7 @@ Mojolicious - Real-time web framework
   # Action
   sub hello {
     my $self = shift;
-    $self->render_text('Hello World!');
+    $self->render(text => 'Hello World!');
   }
 
 =head1 DESCRIPTION
@@ -239,7 +228,7 @@ Take a look at our excellent documentation in L<Mojolicious::Guides>!
 L<Mojolicious> inherits all attributes from L<Mojo> and implements the
 following new ones.
 
-=head2 C<commands>
+=head2 commands
 
   my $commands = $app->commands;
   $app         = $app->commands(Mojolicious::Commands->new);
@@ -250,7 +239,7 @@ L<Mojolicious::Commands> object.
   # Add another namespace to load commands from
   push @{$app->commands->namespaces}, 'MyApp::Command';
 
-=head2 C<controller_class>
+=head2 controller_class
 
   my $class = $app->controller_class;
   $app      = $app->controller_class('Mojolicious::Controller');
@@ -258,13 +247,13 @@ L<Mojolicious::Commands> object.
 Class to be used for the default controller, defaults to
 L<Mojolicious::Controller>.
 
-=head2 C<mode>
+=head2 mode
 
   my $mode = $app->mode;
   $app     = $app->mode('production');
 
 The operating mode for your application, defaults to the value of the
-C<MOJO_MODE> environment variable or C<development>. You can also add per
+MOJO_MODE environment variable or C<development>. You can also add per
 mode logic to your application by defining methods named C<${mode}_mode> in
 the application class, which will be called right before C<startup>.
 
@@ -282,7 +271,16 @@ Right before calling C<startup> and mode specific methods, L<Mojolicious>
 will pick up the current mode, name the log file after it and raise the log
 level from C<debug> to C<info> if it has a value other than C<development>.
 
-=head2 C<plugins>
+=head2 moniker
+
+  my $moniker = $app->moniker;
+  $app        = $app->moniker('foo_bar');
+
+Moniker of this application, often used as default filename for configuration
+files and the like, defaults to decamelizing the application class with
+L<Mojo::Util/"decamelize">.
+
+=head2 plugins
 
   my $plugins = $app->plugins;
   $app        = $app->plugins(Mojolicious::Plugins->new);
@@ -293,7 +291,7 @@ C<plugin> method below if you want to load a plugin.
   # Add another namespace to load plugins from
   push @{$app->plugins->namespaces}, 'MyApp::Plugin';
 
-=head2 C<renderer>
+=head2 renderer
 
   my $renderer = $app->renderer;
   $app         = $app->renderer(Mojolicious::Renderer->new);
@@ -309,7 +307,7 @@ contain more information.
   # Add another class with templates in DATA section
   push @{$app->renderer->classes}, 'Mojolicious::Plugin::Fun';
 
-=head2 C<routes>
+=head2 routes
 
   my $routes = $app->routes;
   $app       = $app->routes(Mojolicious::Routes->new);
@@ -317,34 +315,38 @@ contain more information.
 The router, defaults to a L<Mojolicious::Routes> object. You use this in your
 startup method to define the url endpoints for your application.
 
-  sub startup {
-    my $self = shift;
+  # Add routes
+  my $r = $app->routes;
+  $r->get('/foo/bar')->to('test#foo', title => 'Hello Mojo!');
+  $r->post('/baz')->to('test#baz');
 
-    my $r = $self->routes;
-    $r->get('/:controller/:action')->to('test#welcome');
-  }
+  # Add another namespace to load controllers from
+  push @{$app->routes->namespaces}, 'MyApp::Controller';
 
-=head2 C<secret>
+=head2 secret
 
   my $secret = $app->secret;
   $app       = $app->secret('passw0rd');
 
 A secret passphrase used for signed cookies and the like, defaults to the
 application name which is not very secure, so you should change it!!! As long
-as you are using the unsecure default there will be debug messages in the log
+as you are using the insecure default there will be debug messages in the log
 file reminding you to change your passphrase.
 
-=head2 C<sessions>
+=head2 sessions
 
   my $sessions = $app->sessions;
   $app         = $app->sessions(Mojolicious::Sessions->new);
 
-Simple signed cookie based sessions, defaults to a L<Mojolicious::Sessions>
+Signed cookie based session manager, defaults to a L<Mojolicious::Sessions>
 object. You can usually leave this alone, see
 L<Mojolicious::Controller/"session"> for more information about working with
 session data.
 
-=head2 C<static>
+  # Change name of cookie used for all sessions
+  $app->sessions->cookie_name('mysession');
+
+=head2 static
 
   my $static = $app->static;
   $app       = $app->static(Mojolicious::Static->new);
@@ -358,7 +360,7 @@ L<Mojolicious::Static> object.
   # Add another class with static files in DATA section
   push @{$app->static->classes}, 'Mojolicious::Plugin::Fun';
 
-=head2 C<types>
+=head2 types
 
   my $types = $app->types;
   $app      = $app->types(Mojolicious::Types->new);
@@ -366,6 +368,7 @@ L<Mojolicious::Static> object.
 Responsible for connecting file extensions with MIME types, defaults to a
 L<Mojolicious::Types> object.
 
+  # Add custom MIME type
   $app->types->type(twt => 'text/tweet');
 
 =head1 METHODS
@@ -373,23 +376,23 @@ L<Mojolicious::Types> object.
 L<Mojolicious> inherits all methods from L<Mojo> and implements the following
 new ones.
 
-=head2 C<new>
+=head2 new
 
   my $app = Mojolicious->new;
 
 Construct a new L<Mojolicious> application, calling C<${mode}_mode> and
 C<startup> in the process. Will automatically detect your home directory and
 set up logging based on your current operating mode. Also sets up the
-renderer, static dispatcher and a default set of plugins.
+renderer, static file server and a default set of plugins.
 
-=head2 C<build_tx>
+=head2 build_tx
 
   my $tx = $app->build_tx;
 
 Transaction builder, defaults to building a L<Mojo::Transaction::HTTP>
 object.
 
-=head2 C<defaults>
+=head2 defaults
 
   my $defaults = $app->defaults;
   my $foo      = $app->defaults('foo');
@@ -404,22 +407,22 @@ request.
   my $foo = $app->defaults->{foo};
   delete $app->defaults->{foo};
 
-=head2 C<dispatch>
+=head2 dispatch
 
-  $app->dispatch($c);
+  $app->dispatch(Mojolicious::Controller->new);
 
 The heart of every Mojolicious application, calls the C<static> and C<routes>
 dispatchers for every request and passes them a L<Mojolicious::Controller>
 object.
 
-=head2 C<handler>
+=head2 handler
 
-  $app->handler($tx);
-  $app->handler($c);
+  $app->handler(Mojo::Transaction::HTTP->new);
+  $app->handler(Mojolicious::Controller->new);
 
 Sets up the default controller and calls process for every request.
 
-=head2 C<helper>
+=head2 helper
 
   $app->helper(foo => sub {...});
 
@@ -427,32 +430,35 @@ Add a new helper that will be available as a method of the controller object
 and the application object, as well as a function in C<ep> templates.
 
   # Helper
-  $app->helper(add => sub { $_[1] + $_[2] });
+  $app->helper(cache => sub { state $cache = {} });
 
   # Controller/Application
-  my $result = $self->add(2, 3);
+  $self->cache->{foo} = 'bar';
+  my $result = $self->cache->{foo};
 
   # Template
-  %= add 2, 3
+  % cache->{foo} = 'bar';
+  %= cache->{foo}
 
-=head2 C<hook>
+=head2 hook
 
   $app->hook(after_dispatch => sub {...});
 
-Extend L<Mojolicious> with hooks.
+Extend L<Mojolicious> with hooks, which allow code to be shared with all
+requests indiscriminately.
 
   # Dispatchers will not run if there's already a response code defined
   $app->hook(before_dispatch => sub {
     my $c = shift;
     $c->render(text => 'Skipped dispatchers!')
-      if $c->req->url->path->contains('/do_not_dispatch');
+      if $c->req->url->path->to_route =~ /do_not_dispatch/;
   });
 
 These hooks are currently available and are emitted in the listed order:
 
 =over 2
 
-=item B<after_build_tx>
+=item after_build_tx
 
 Emitted right after the transaction is built and before the HTTP request gets
 parsed.
@@ -463,13 +469,13 @@ parsed.
   });
 
 This is a very powerful hook and should not be used lightly, it makes some
-rather advanced features such as upload progress bars possible, just note that
-it will not work for embedded applications. (Passed the transaction and
+rather advanced features such as upload progress bars possible. Note that this
+hook will not work for embedded applications. (Passed the transaction and
 application object)
 
-=item B<before_dispatch>
+=item before_dispatch
 
-Emitted right before the static dispatcher and router start their work.
+Emitted right before the static file server and router start their work.
 
   $app->hook(before_dispatch => sub {
     my $c = shift;
@@ -479,23 +485,52 @@ Emitted right before the static dispatcher and router start their work.
 Very useful for rewriting incoming requests and other preprocessing tasks.
 (Passed the default controller object)
 
-=item B<after_static_dispatch>
+=item after_static
 
-Emitted in reverse order after the static dispatcher determined if a static
-file should be served and before the router starts its work.
+Emitted after a static file response has been generated by the static file
+server.
 
-  $app->hook(after_static_dispatch => sub {
+  $app->hook(after_static => sub {
     my $c = shift;
     ...
   });
 
-Mostly used for custom dispatchers and post-processing static file responses.
-(Passed the default controller object)
+Mostly used for post-processing static file responses. (Passed the default
+controller object)
 
-=item B<after_dispatch>
+=item before_routes
+
+Emitted after the static file server determined if a static file should be
+served and before the router starts its work.
+
+  $app->hook(before_routes => sub {
+    my $c = shift;
+    ...
+  });
+
+Mostly used for custom dispatchers and collecting metrics. (Passed the default
+controller object)
+
+=item after_render
+
+Emitted after content has been generated by the renderer that is not partial.
+Note that this hook can trigger out of order due to its dynamic nature, and
+with embedded applications will only work for the application that is
+rendering.
+
+  $app->hook(after_render => sub {
+    my ($c, $output, $format) = @_;
+    ...
+  });
+
+Mostly used for post-processing dynamically generated content. (Passed the
+current controller object, a reference to the content and the format)
+
+=item after_dispatch
 
 Emitted in reverse order after a response has been rendered. Note that this
-hook can trigger before C<after_static_dispatch> due to its dynamic nature.
+hook can trigger out of order due to its dynamic nature, and with embedded
+applications will only work for the application that is rendering.
 
   $app->hook(after_dispatch => sub {
     my $c = shift;
@@ -505,7 +540,7 @@ hook can trigger before C<after_static_dispatch> due to its dynamic nature.
 Useful for rewriting outgoing responses and other post-processing tasks.
 (Passed the current controller object)
 
-=item B<around_dispatch>
+=item around_dispatch
 
 Emitted right before the C<before_dispatch> hook and wraps around the whole
 dispatch process, so you have to manually forward to the next hook if you want
@@ -522,12 +557,12 @@ and a call to C<dispatch> the last, yours will be in between.
 
 This is a very powerful hook and should not be used lightly, it allows you to
 customize application wide exception handling for example, consider it the
-sledgehammer in your toolbox. (Passed a closure leading to the next hook and
+sledgehammer in your toolbox. (Passed a callback leading to the next hook and
 the default controller object)
 
 =back
 
-=head2 C<plugin>
+=head2 plugin
 
   $app->plugin('some_thing');
   $app->plugin('some_thing', foo => 23);
@@ -539,79 +574,21 @@ the default controller object)
   $app->plugin('MyApp::Plugin::SomeThing', foo => 23);
   $app->plugin('MyApp::Plugin::SomeThing', {foo => 23});
 
-Load a plugin with L<Mojolicious::Plugins/"register_plugin">.
+Load a plugin, for a full list of example plugins included in the
+L<Mojolicious> distribution see L<Mojolicious::Plugins/"PLUGINS">.
 
-These plugins are included in the L<Mojolicious> distribution as examples:
-
-=over 2
-
-=item L<Mojolicious::Plugin::Charset>
-
-Change the application charset.
-
-=item L<Mojolicious::Plugin::Config>
-
-Perl-ish configuration files.
-
-=item L<Mojolicious::Plugin::DefaultHelpers>
-
-General purpose helper collection, loaded automatically.
-
-=item L<Mojolicious::Plugin::EPLRenderer>
-
-Renderer for plain embedded Perl templates, loaded automatically.
-
-=item L<Mojolicious::Plugin::EPRenderer>
-
-Renderer for more sophisiticated embedded Perl templates, loaded
-automatically.
-
-=item L<Mojolicious::Plugin::HeaderCondition>
-
-Route condition for all kinds of headers, loaded automatically.
-
-=item L<Mojolicious::Plugin::I18N>
-
-Internationalization helpers.
-
-=item L<Mojolicious::Plugin::JSONConfig>
-
-JSON configuration files.
-
-=item L<Mojolicious::Plugin::Mount>
-
-Mount whole L<Mojolicious> applications.
-
-=item L<Mojolicious::Plugin::PODRenderer>
-
-Renderer for POD files and documentation browser.
-
-=item L<Mojolicious::Plugin::PoweredBy>
-
-Add an C<X-Powered-By> header to outgoing responses, loaded automatically.
-
-=item L<Mojolicious::Plugin::RequestTimer>
-
-Log timing information, loaded automatically.
-
-=item L<Mojolicious::Plugin::TagHelpers>
-
-Template specific helper collection, loaded automatically.
-
-=back
-
-=head2 C<start>
+=head2 start
 
   $app->start;
   $app->start(@ARGV);
 
-Start the command line interface for your application with
-L<Mojolicious::Commands/"start">.
+Start the command line interface for your application, for a full list of
+commands available by default see L<Mojolicious::Commands/"COMMANDS">.
 
   # Always start daemon and ignore @ARGV
   $app->start('daemon', '-l', 'http://*:8080');
 
-=head2 C<startup>
+=head2 startup
 
   $app->startup;
 
@@ -628,32 +605,12 @@ startup. Meant to be overloaded in a subclass.
 In addition to the attributes and methods above you can also call helpers on
 L<Mojolicious> objects. This includes all helpers from
 L<Mojolicious::Plugin::DefaultHelpers> and L<Mojolicious::Plugin::TagHelpers>.
-Note that application helpers are always called with a new C<controller_class>
+Note that application helpers are always called with a new default controller
 object, so they can't depend on or change controller state, which includes
 request, response and stash.
 
   $app->log->debug($app->dumper({foo => 'bar'}));
 
-=head1 SUPPORT
-
-=head2 Web
-
-L<http://mojolicio.us>
-
-=head2 IRC
-
-C<#mojo> on C<irc.perl.org>
-
-=head2 Mailing-List
-
-L<http://groups.google.com/group/mojolicious>
-
-=head1 DEVELOPMENT
-
-=head2 Repository
-
-L<http://github.com/kraih/mojo>
-
 =head1 BUNDLED FILES
 
 The L<Mojolicious> distribution includes a few files with different licenses
@@ -661,20 +618,20 @@ that have been bundled for internal use.
 
 =head2 Mojolicious Artwork
 
-  Copyright (C) 2010-2012, Sebastian Riedel.
+  Copyright (C) 2010-2013, Sebastian Riedel.
 
 Licensed under the CC-SA License, Version 3.0
 L<http://creativecommons.org/licenses/by-sa/3.0>.
 
 =head2 jQuery
 
-  Copyright (C) 2011, John Resig.
+  Copyright (C) 2005, 2013 jQuery Foundation, Inc.
 
 Licensed under the MIT License, L<http://creativecommons.org/licenses/MIT>.
 
 =head2 prettify.js
 
-  Copyright (C) 2006, Google Inc.
+  Copyright (C) 2006, 2013 Google Inc.
 
 Licensed under the Apache License, Version 2.0
 L<http://www.apache.org/licenses/LICENSE-2.0>.
@@ -684,6 +641,8 @@ L<http://www.apache.org/licenses/LICENSE-2.0>.
 Every major release of L<Mojolicious> has a code name, these are the ones that
 have been used in the past.
 
+3.0, C<Rainbow> (u1F308)
+
 2.0, C<Leaf Fluttering In Wind> (u1F343)
 
 1.4, C<Smiling Face With Sunglasses> (u1F60E)
@@ -700,6 +659,11 @@ have been used in the past.
 
 0.999920, C<Snowman> (u2603)
 
+=head1 SPONSORS
+
+Some of the work on this distribution has been sponsored by
+L<The Perl Foundation|http://www.perlfoundation.org>, thank you!
+
 =head1 PROJECT FOUNDER
 
 Sebastian Riedel, C<sri@cpan.org>
@@ -714,6 +678,8 @@ Abhijit Menon-Sen, C<ams@cpan.org>
 
 Glen Hinkle, C<tempire@cpan.org>
 
+Joel Berger, C<jberger@cpan.org>
+
 Marcus Ramberg, C<mramberg@cpan.org>
 
 =back
@@ -740,9 +706,11 @@ Andre Vieth
 
 Andreas Jaekel
 
+Andreas Koenig
+
 Andrew Fresh
 
-Andreas Koenig
+Andrey Khozov
 
 Andy Grundman
 
@@ -782,14 +750,22 @@ Daniel Kimsey
 
 Danijel Tasov
 
+Danny Thomas
+
 David Davis
 
+David Webb
+
 Diego Kuperman
 
 Dmitriy Shalashov
 
 Dmitry Konstantinov
 
+Dominik Jarmulowicz
+
+Dominique Dumont
+
 Douglas Christopher Wilson
 
 Eugene Toropov
@@ -802,10 +778,14 @@ Henry Tang
 
 Hideki Yamamura
 
+Ilya Chesnokov
+
 James Duncan
 
 Jan Jona Javorsek
 
+Jan Schmidt
+
 Jaroslav Muhin
 
 Jesse Vincent
@@ -820,7 +800,7 @@ Kazuhiro Shibuya
 
 Kevin Old
 
-KITAMURA Akatsuki
+Kitamura Akatsuki
 
 Lars Balker Rasmussen
 
@@ -832,6 +812,8 @@ Maik Fischer
 
 Mark Stosberg
 
+Marty Tennison
+
 Matthew Lineen
 
 Maksym Komar
@@ -850,6 +832,8 @@ Moritz Lenz
 
 Neil Watkiss
 
+Nic Sandfield
+
 Nils Diewald
 
 Oleg Zhelo
@@ -882,6 +866,8 @@ Ryan Jendoubi
 
 Sascha Kiefer
 
+Scott Wiersdorf
+
 Sergey Zasenko
 
 Simon Bertrang
@@ -900,8 +886,6 @@ Tatsuhiko Miyagawa
 
 Terrence Brannon
 
-The Perl Foundation
-
 Tomas Znamenacek
 
 Ulrich Habel
@@ -928,9 +912,13 @@ Zak B. Elep
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2012, Sebastian Riedel.
+Copyright (C) 2008-2013, Sebastian Riedel.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
 
+=head1 SEE ALSO
+
+L<Mojolicious::Guides>, L<http://mojolicio.us>.
+
 =cut
