@@ -1,12 +1,6 @@
 package Mojolicious::Plugin::PoweredBy;
 use Mojo::Base 'Mojolicious::Plugin';
 
-# "It's just like the story of the grasshopper and the octopus.
-#  All year long, the grasshopper kept burying acorns for the winter,
-#  while the octopus mooched off his girlfriend and watched TV.
-#  But then the winter came, and the grasshopper died,
-#  and the octopus ate all his acorns.
-#  And also he got a racecar. Is any of this getting through to you?"
 sub register {
   my ($self, $app, $conf) = @_;
   my $name = $conf->{name} || 'Mojolicious (Perl)';
@@ -42,22 +36,23 @@ example for learning to build new plugins, you're welcome to fork it.
 
 L<Mojolicious::Plugin::PoweredBy> supports the following options.
 
-=head2 C<name>
+=head2 name
 
   plugin PoweredBy => (name => 'MyApp 1.0');
 
-Value for C<X-Powered-By> header.
+Value for C<X-Powered-By> header, defaults to C<Mojolicious (Perl)>.
 
 =head1 METHODS
 
 L<Mojolicious::Plugin::PoweredBy> inherits all methods from
 L<Mojolicious::Plugin> and implements the following new ones.
 
-=head2 C<register>
+=head2 register
 
-  $plugin->register($app, $conf);
+  $plugin->register(Mojolicious->new);
+  $plugin->register(Mojolicious->new, {name => 'MyFramework 1.0'});
 
-Register plugin hooks in L<Mojolicious> application.
+Register hooks in L<Mojolicious> application.
 
 =head1 SEE ALSO
 
